@@ -7,7 +7,7 @@ package Image::Info::JPEG;
 
 # maintained by Tels 2007 - 2008
 
-$VERSION = 0.04;
+$VERSION = 0.07;
 
 =begin register
 
@@ -275,7 +275,11 @@ sub process_app1_exif
     }
 
     require Image::TIFF;
-    my $t = Image::TIFF->new(\$data);
+    my $t = eval { Image::TIFF->new(\$data) };
+    if (!$t) {
+	$info->push_info(0, "Warn", "Cannot parse APP1 EXIF segment");
+	return;
+    }
 
 
     for my $i (0 .. $t->num_ifds - 1) {
@@ -293,7 +297,7 @@ sub process_app1_exif
 	}
 
 	# If we find JPEGInterchangeFormat/JPEGInterchangeFormatLngth,
-	# then we should apply process_file kind of recusively to extract
+	# then we should apply process_file kind of recursively to extract
 	# information of this (thumbnail) image file...
 	if (my($ipos) = $info->get_info($i, "JPEGInterchangeFormat", 1)) {
 	    my($ilen) = $info->get_info($i, "JPEGInterchangeFormatLength", 1);
@@ -302,9 +306,14 @@ sub process_app1_exif
 		my $jdata = substr($data, $ipos, $ilen);
 		#$info->push_info($i, "JPEGImage" => $jdata);
 
-		with_io_string {
-		    _process_file($info, $_, $i);
-		} $jdata;
+		if ($jdata) {
+		    eval {
+			with_io_string {
+			    _process_file($info, $_, $i);
+			} $jdata;
+		    };
+		    $info->push_info($i, "error" => $@) if $@;
+		}
 	    }
 	}
 
